==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/healthbot/kotlin/inputs/ListBotSecretsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.healthbot.kotlin.inputs

import com.pulumi.azurenative.healthbot.inputs.ListBotSecretsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property botName The name of the Bot resource.
 * @property resourceGroupName The name of the Bot resource group in the user subscription.
 */
public data class ListBotSecretsPlainArgs(
    public val botName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.healthbot.inputs.ListBotSecretsPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.healthbot.inputs.ListBotSecretsPlainArgs =
        com.pulumi.azurenative.healthbot.inputs.ListBotSecretsPlainArgs.builder()
            .botName(botName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListBotSecretsPlainArgs].
 */
@PulumiTagMarker
public class ListBotSecretsPlainArgsBuilder internal constructor() {
    private var botName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the Bot resource.
     */
    @JvmName("oalgomgrnnkdjhsq")
    public suspend fun botName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.botName = mapped
    }

    /**
     * @param value The name of the Bot resource group in the user subscription.
     */
    @JvmName("apyyvwudsxblnkhj")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): ListBotSecretsPlainArgs = ListBotSecretsPlainArgs(
        botName = botName ?: throw PulumiNullFieldException("botName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/healthbot/kotlin/inputs/ListBotSecretsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.healthbot.kotlin.inputs

import com.pulumi.azurenative.healthbot.inputs.ListBotSecretsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property botName The name of the Bot resource.
 * @property resourceGroupName The name of the Bot resource group in the user subscription.
 */
public data class ListBotSecretsPlainArgs(
    public val botName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.healthbot.inputs.ListBotSecretsPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.healthbot.inputs.ListBotSecretsPlainArgs =
        com.pulumi.azurenative.healthbot.inputs.ListBotSecretsPlainArgs.builder()
            .botName(botName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListBotSecretsPlainArgs].
 */
@PulumiTagMarker
public class ListBotSecretsPlainArgsBuilder internal constructor() {
    private var botName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the Bot resource.
     */
    @JvmName("fmsqnuefgnuymxer")
    public suspend fun botName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.botName = mapped
    }

    /**
     * @param value The name of the Bot resource group in the user subscription.
     */
    @JvmName("fbjwmchgfiftdjll")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): ListBotSecretsPlainArgs = ListBotSecretsPlainArgs(
        botName = botName ?: throw PulumiNullFieldException("botName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
